@@ -1,5 +1,5 @@
 #--
-# Copyright (c) 2005-2008 Robert Aman
+# UUIDTools, Copyright (c) 2005-2008 Bob Aman
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -21,12 +21,15 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #++
 
-class UUID
-  module UUID_TOOLS_VERSION #:nodoc:
-    MAJOR = 1
-    MINOR = 0
-    TINY  = 3
+# Used to prevent the class/module from being loaded more than once
+unless defined? UUID::VERSION
+  class UUID
+    module VERSION #:nodoc:
+      MAJOR = 2
+      MINOR = 1
+      TINY  = 1
 
-    STRING = [MAJOR, MINOR, TINY].join('.')
+      STRING = [MAJOR, MINOR, TINY].join('.')
+    end
   end
 end
